==> akonadi-contacts-17.08.0.tar.xz: akonadi-contacts-17.08.0/src/contact-editor/editor/generalinfoeditor/nameeditdialog.h <==
/*
    This file is part of Contact Editor.

    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef NAMEEDITDIALOG_H
#define NAMEEDITDIALOG_H

#include "displaynameeditwidget.h"
#include <QDialog>

#include <KContacts/Addressee>

class KLineEdit;
class KComboBox;
class DisplayNameEditWidget;
class NameEditDialog : public QDialog
{
    Q_OBJECT
public:
    explicit NameEditDialog(QWidget *parent = nullptr);

    void setFamilyName(const QString &name);
    QString familyName() const;

    void setGivenName(const QString &name);
    QString givenName() const;

    void setPrefix(const QString &prefix);
    QString prefix() const;

    void setSuffix(const QString &suffix);
    QString suffix() const;

    void setAdditionalName(const QString &name);
    QString additionalName() const;

    void loadContact(const KContacts::Addressee &contact);
    void storeContact(KContacts::Addressee &contact) const;

    void setDisplayType(DisplayNameEditWidget::DisplayType type);
    DisplayNameEditWidget::DisplayType displayType() const;
private:
    KComboBox *mSuffixCombo;
    KComboBox *mPrefixCombo;
    KLineEdit *mFamilyNameEdit;
    KLineEdit *mGivenNameEdit;
    KLineEdit *mAdditionalNameEdit;
    DisplayNameEditWidget *mDisplayNameEdit;
};

#endif

==> akonadi-contacts-17.12.2.tar.xz: akonadi-contacts-17.12.2/src/contact-editor/editor/generalinfoeditor/nameeditdialog.h <==
/*
    This file is part of Contact Editor.

    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef NAMEEDITDIALOG_H
#define NAMEEDITDIALOG_H

#include "displaynameeditwidget.h"
#include <QDialog>

#include <KContacts/Addressee>

class KLineEdit;
class KComboBox;
class DisplayNameEditWidget;
class NameEditDialog : public QDialog
{
    Q_OBJECT
public:
    explicit NameEditDialog(QWidget *parent = nullptr);

    void setFamilyName(const QString &name);
    QString familyName() const;

    void setGivenName(const QString &name);
    QString givenName() const;

    void setPrefix(const QString &prefix);
    QString prefix() const;

    void setSuffix(const QString &suffix);
    QString suffix() const;

    void setAdditionalName(const QString &name);
    QString additionalName() const;

    void loadContact(const KContacts::Addressee &contact);
    void storeContact(KContacts::Addressee &contact) const;

    void setDisplayType(DisplayNameEditWidget::DisplayType type);
    DisplayNameEditWidget::DisplayType displayType() const;
private:
    KComboBox *mSuffixCombo = nullptr;
    KComboBox *mPrefixCombo = nullptr;
    KLineEdit *mFamilyNameEdit = nullptr;
    KLineEdit *mGivenNameEdit = nullptr;
    KLineEdit *mAdditionalNameEdit = nullptr;
    DisplayNameEditWidget *mDisplayNameEdit = nullptr;
};

#endif
